@@ -21,7 +21,7 @@ makeMBOTerminationMaxIter = function(max.iter) {
     iter = getOptStateLoop(opt.state)
     term = iter > max.iter
     message = if (!term) NA_character_ else sprintf("Maximum number of iterations %i reached with.", max.iter, iter)
-    return(list(term = term, message = message, code = "term.iter"))
+    return(list(term = term, message = message, code = "term.iter", progress = iter / max.iter))
   }
 }
 
@@ -37,7 +37,7 @@ makeMBOTerminationMaxBudget = function(time.budget) {
     time.used = as.numeric(getOptStateTimeUsed(opt.state), units = "secs")
     term = (time.used > time.budget)
     message = if (!term) NA_character_ else sprintf("Time budged %f reached.", time.budget)
-    return(list(term = term, message = message, code = "term.time"))
+    return(list(term = term, message = message, code = "term.time", progress = time.used / time.budget))
   }
 }
 
@@ -51,11 +51,13 @@ makeMBOTerminationMaxExecBudget = function(time.budget) {
   force(time.budget)
   function(opt.state) {
     opt.path = getOptStateOptPath(opt.state)
-    time.used = sum(getOptPathExecTimes(opt.path), na.rm = TRUE)
-
+    exec.times = getOptPathExecTimes(opt.path)
+    time.used = sum(exec.times, na.rm = TRUE)
+    time.used.optimization = sum(exec.times[getOptPathDOB(opt.path)!=0], na.rm = TRUE)
+    time.used.init = sum(exec.times[getOptPathDOB(opt.path)==0], na.rm = TRUE)
     term = (time.used > time.budget)
     message = if (!term) NA_character_ else sprintf("Execution time budged %f reached.", time.budget)
-    return(list(term = term, message = message, code = "term.exectime"))
+    return(list(term = term, message = message, code = "term.exectime", progress = max(time.used.optimization / (time.budget - time.used.init), 0, na.rm = TRUE)))
   }
 }
 
@@ -74,10 +76,11 @@ makeMBOTerminationTargetFunValue = function(target.fun.value) {
     control = getOptProblemControl(opt.problem)
     opt.path = getOptStateOptPath(opt.state)
     opt.dir = if (control$minimize) 1L else -1L
-    current.best = getOptPathEl(opt.path, getOptPathBestIndex((opt.path)))$y
+    init.best = getOptPathY(opt.path)[getOptPathBestIndex(opt.path, dob = 0)]
+    current.best = getOptPathY(opt.path)[getOptPathBestIndex(opt.path)]
     term = (current.best * opt.dir <= target.fun.value * opt.dir)
     message = if (!term) NA_character_ else sprintf("Target function value %f reached.", target.fun.value)
-    return(list(term = term, message = message, code = "term.yval"))
+    return(list(term = term, message = message, code = "term.yval", progress = abs(init.best - current.best)/abs(init.best - target.fun.value)))
   }
 }
 
@@ -92,8 +95,9 @@ makeMBOTerminationMaxEvals = function(max.evals) {
   function(opt.state) {
     opt.path = getOptStateOptPath(opt.state)
     evals = getOptPathLength(opt.path)
+    init.evals = sum(getOptPathDOB(opt.path)==0)
     term = (evals >= max.evals)
     message = if (!term) NA_character_ else sprintf("Maximal number of function evaluations %i reached.", max.evals)
-    return(list(term = term, message = message, code = "term.feval"))
+    return(list(term = term, message = message, code = "term.feval", progress = (evals-init.evals) / (max.evals-init.evals)))
   }
 }
