@@ -1,11 +1,4 @@
-# setting R_TESTS to empty string because of
-# https://github.com/hadley/testthat/issues/144
-# revert this when that issue in R is fixed.
-Sys.setenv("R_TESTS" = "")
-
 library(testthat)
-library(checkmate)
-library(mlrMBO)
 
 # the unit tests take pretty long, that can be a problem on WB and cran (and maybe annoying locally)
 # so we run all tests only on travis and if a certain user env var is set
